ExtendGenerator class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

clipboardData Future<String?>
Retrieves the current contents from the system clipboard.
no setter
randomColor Color
Generates a random opaque Color.
no setter
randomEmail String
Generates a mock email address using common domains (e.g., gmail.com, yahoo.com).
no setter
uuid String
Generates a Mock UUID (v4 format).
no setter

Static Methods

randomCreditCard({CardType type = CardType.visa}) String
Generates a specific type of Mock Credit Card Number.
randomDate({int daysBack = 365}) DateTime
Generates a random DateTime within the past daysBack.
streamOf<T>(T generator(int index), {int count = 10, Duration interval = const Duration(seconds: 1)}) Stream<T>
Simulates a live stream of data that emits count items.
weightedBool(double chance) bool
Returns true based on a specific probability chance (0.0 to 1.0).