GlobalColorExtensions extension

on

Properties

isDark bool

Available on Color, provided by the GlobalColorExtensions extension

Checks if the Color is perceived as dark (luminance is below 0.5).
no setter
isLight bool

Available on Color, provided by the GlobalColorExtensions extension

Checks if the Color is perceived as light (luminance is 0.5 or above).
no setter
luminance double

Available on Color, provided by the GlobalColorExtensions extension

Computes the relative luminance of this Color using the sRGB color space.
no setter
toMaterialColor MaterialColor

Available on Color, provided by the GlobalColorExtensions extension

Generates a full 10-shade MaterialColor swatch (50-900) from a single base color.
no setter

Methods

getLighterShade(double factor) Color

Available on Color, provided by the GlobalColorExtensions extension

Lightens the color by a specified factor.
toHex({bool hashSign = true, bool withAlpha = false}) String

Available on Color, provided by the GlobalColorExtensions extension

Converts the color to a hexadecimal string representation.