NumberDurationExtensions extension

on

Properties

days → Duration

Available on int, provided by the NumberDurationExtensions extension

Converts the integer value to a Duration object representing days.
no setter
hours → Duration

Available on int, provided by the NumberDurationExtensions extension

Converts the integer value to a Duration object representing hours.
no setter
microSeconds → Duration

Available on int, provided by the NumberDurationExtensions extension

Converts the integer value to a Duration object representing microseconds.
no setter
milliSeconds → Duration

Available on int, provided by the NumberDurationExtensions extension

Converts the integer value to a Duration object representing milliseconds.
no setter
minutes → Duration

Available on int, provided by the NumberDurationExtensions extension

Converts the integer value to a Duration object representing minutes.
no setter
seconds → Duration

Available on int, provided by the NumberDurationExtensions extension

Converts the integer value to a Duration object representing seconds.
no setter