DiceBearStyle enum
Values
- adventurer → const DiceBearStyle
- adventurerNeutral → const DiceBearStyle
- avataaars → const DiceBearStyle
- avataaarsNeutral → const DiceBearStyle
- bigEars → const DiceBearStyle
- bigEarsNeutral → const DiceBearStyle
- bigSmile → const DiceBearStyle
- bottts → const DiceBearStyle
- botttsNeutral → const DiceBearStyle
- croodles → const DiceBearStyle
- croodlesNeutral → const DiceBearStyle
- dylan → const DiceBearStyle
- funEmoji → const DiceBearStyle
- glass → const DiceBearStyle
- icons → const DiceBearStyle
- identicon → const DiceBearStyle
- initials → const DiceBearStyle
- lorelei → const DiceBearStyle
- loreleiNeutral → const DiceBearStyle
- micah → const DiceBearStyle
- miniavs → const DiceBearStyle
- notionists → const DiceBearStyle
- notionistsNeutral → const DiceBearStyle
- openPeeps → const DiceBearStyle
- personas → const DiceBearStyle
- pixelArt → const DiceBearStyle
- pixelArtNeutral → const DiceBearStyle
- rings → const DiceBearStyle
- shapes → const DiceBearStyle
- thumbs → const DiceBearStyle
Properties
- apiName → String
-
Converts the enum to the API-friendly string format (kebab-case).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DiceBearStyle> - A constant List of the values in this enum, in order of their declaration.